Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9)

Unified Diff: media/audio/audio_output_controller.h

Issue 10830268: Allow audio system to handle synchronized low-latency audio I/O (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/audio/audio_output_controller.h
===================================================================
--- media/audio/audio_output_controller.h (revision 155897)
+++ media/audio/audio_output_controller.h (working copy)
@@ -92,9 +92,10 @@
// prepare more data and perform synchronization.
virtual void UpdatePendingBytes(uint32 bytes) = 0;
// Attempt to completely fill |audio_bus|, return the actual number of
// frames that could be read.
- virtual int Read(AudioBus* audio_bus) = 0;
+ // |source| may optionally be provided for input data.
+ virtual int Read(AudioBus* source, AudioBus* dest) = 0;
DaleCurtis 2012/09/11 09:44:39 This is a bit confusing now; SyncReader and Read()
scherkus (not reviewing) 2012/09/11 12:13:00 Do you have a suggestion for a name? Perhaps we ca
DaleCurtis 2012/09/11 12:22:23 TODO-ify is fine with me. No suggestions that I ac
// Close this synchronous reader.
virtual void Close() = 0;
@@ -146,6 +147,9 @@
// AudioSourceCallback methods.
virtual int OnMoreData(AudioBus* audio_bus,
AudioBuffersState buffers_state) OVERRIDE;
+ virtual int OnMoreIOData(AudioBus* source,
+ AudioBus* dest,
+ AudioBuffersState buffers_state) OVERRIDE;
virtual void OnError(AudioOutputStream* stream, int code) OVERRIDE;
virtual void WaitTillDataReady() OVERRIDE;
@@ -92,9 +92,10 @@
// prepare more data and perform synchronization.
virtual void UpdatePendingBytes(uint32 bytes) = 0;
- // Attempt to completely fill |audio_bus|, return the actual number of
+ // Attempt to completely fill |dest|, return the actual number of
// frames that could be read.

Powered by Google App Engine
This is Rietveld 408576698